@@ -85,6 +85,9 @@ class PrismaCloudAPIMixin():
             if self.token:
                 request_headers['x-redlock-auth'] = self.token
             body_params_json = json.dumps(body_params)
+            self.debug_print('API URL: %s' % url)
+            self.debug_print('API Query Params: %s' % query_params)
+            self.debug_print('API Body Params: %s' % body_params_json)
             api_response = requests.request(action, url, headers=request_headers, params=query_params, data=body_params_json, verify=self.verify, timeout=self.timeout)
             if self.debug:
                 print('API Response Status Code: %s' % api_response.status_code)
@@ -101,11 +104,11 @@ class PrismaCloudAPIMixin():
                     return api_response.content.decode('utf-8')
                 try:
                     result = json.loads(api_response.content)
-                    if result is None:
-                        self.logger.error('JSON returned None, API: (%s) with query params: (%s) and body params: (%s) parsing response: (%s)' % (url, query_params, body_params, api_response.content))
-                        if force:
-                            return results # or continue
-                        self.error_and_exit(api_response.status_code, 'JSON returned None, API: (%s) with query params: (%s) and body params: (%s) parsing response: (%s)' % (url, query_params, body_params, api_response.content))
+                    #if result is None:
+                    #    self.logger.error('JSON returned None, API: (%s) with query params: (%s) and body params: (%s) parsing response: (%s)' % (url, query_params, body_params, api_response.content))
+                    #    if force:
+                    #        return results # or continue
+                    #    self.error_and_exit(api_response.status_code, 'JSON returned None, API: (%s) with query params: (%s) and body params: (%s) parsing response: (%s)' % (url, query_params, body_params, api_response.content))
                 except ValueError:
                     self.logger.error('JSON raised ValueError, API: (%s) with query params: (%s) and body params: (%s) parsing response: (%s)' % (url, query_params, body_params, api_response.content))
                     if force:
